<?php
header("Content-Type: text/css");

if (isset($_GET['wd']) && !empty($_GET['wd'])){
	$width = $_GET['wd'];
}else{
	$width = '625';
}

	$triggerwidht = $width-50;


?>

h2.trigger {
    background: url("trigger.gif") no-repeat scroll 0 0 transparent;
    background-size: 100% 60px;
    color: #333333;
    cursor: pointer;
    font-size: 1.2em;
    font-weight: normal;
    height: 30px;
    line-height: 30px;
    margin: 0 0 5px;
    padding: 0 0 0 50px;
    width: <?php echo $triggerwidht; ?>px;
}
h2.trigger:hover {
    color: #666666;
}
h2.active {
    background-position: left bottom;
}
.toggle_container {
    background: url("toggle_block_stretch.gif") repeat-y scroll left top #F0F0F0;
    background-size: 100% auto;
    border-top: 1px solid #D6D6D6;
    clear: both;
    /*font-size: 1.2em;*/
    margin: 0 0 5px;
    overflow: hidden;
    padding: 0;
    width: <?php echo $width; ?>px;
}
.toggle_container .block {
    background: url("toggle_block_btm.gif") no-repeat scroll left bottom transparent;
    background-size:100% auto;
    padding: 20px;
}
.toggle_container .block p {
    margin: 5px 0;
    padding: 5px 0;
}
.toggle_container h3 {
    border-bottom: 1px dashed #CCCCCC;
    margin: 0 0 10px;
    padding: 0 0 5px;
}
.toggle_container img {
    background: none repeat scroll 0 0 #DDDDDD;
    border: 1px solid #CCCCCC;
    /*float: left;*/
    margin: 10px 15px 15px 0;
    padding: 5px;
}